package com.ibm.oti.shared;

/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 1998, 2010  All Rights Reserved
 */

import java.nio.ByteBuffer;

/**
 * Implementation of SharedDataHelper.
 * <p>
 * @author		OTI
 * @version		initial
 *
 * @see SharedDataHelper
 * @see SharedAbstractHelper
 */
public class SharedDataHelperImpl extends SharedAbstractHelper implements SharedDataHelper {
	/* Not public - should only be created by factory */
	SharedDataHelperImpl(ClassLoader loader, int id, boolean canFind, boolean canStore) {
		initialize(loader, id, canFind, canStore);
	}

	private native ByteBuffer findSharedDataImpl(int id, String token);

	private native ByteBuffer storeSharedDataImpl(ClassLoader loader, int id, String token, ByteBuffer data);

	public ByteBuffer findSharedData(String token) {
		if (!canFind) {
			return null;
		}
		if (!checkReadPermission()) {
			printVerboseError("Read permission denied. Returning null.");
			return null;
		}
		if (token==null) {
			printVerboseError("Cannot call findSharedData with null token. Returning null.");
			return null;
		}
		return findSharedDataImpl(this.id, token);
	}

	public ByteBuffer storeSharedData(String token, ByteBuffer data) {
		if (!canStore) {
			return null;
		}
		if (!checkWritePermission()) {
			printVerboseError("Write permission denied. Returning null.");
			return null;
		}
		if (token==null) {
			printVerboseError("Cannot call storeSharedData with null token. Returning null.");
			return null;
		}
		if (data!=null && !data.isDirect()) {
			printVerboseError("Cannot call storeSharedData with a non-direct ByteBuffer. Returning null.");
			return null;
		}
		return storeSharedDataImpl(getClassLoader(),this.id, token, data);
	}

	String getHelperType() {
		return "SharedDataHelper";
	}
}
